@@ -50,7 +50,7 @@ class OkexCoin:
         return okex
 
     def watch(self):
-        if self.money > 52:
+        if self.money > 52 or self.money < 48:
             self.sell()
 
     def __str__(self):
